@@ -116,22 +116,20 @@ From 1.1 to 2.0
 @group Response Encodings: ENCODE_KVFORM, ENCODE_HTML_FORM, ENCODE_URL
 """
 
-import logging
-import time
-import warnings
+import time, warnings
 from copy import deepcopy
 
-from openid import cryptutil, kvform, oidutil
-from openid.association import Association, default_negotiator, getSecretSize
+from openid import cryptutil
+from openid import oidutil
+from openid import kvform
 from openid.dh import DiffieHellman
-from openid.message import (IDENTIFIER_SELECT, OPENID1_URL_LIMIT, OPENID2_NS, OPENID_NS, InvalidNamespace,
-                            InvalidOpenIDNamespace, Message)
-from openid.server.trustroot import TrustRoot, verifyReturnTo
 from openid.store.nonce import mkNonce
+from openid.server.trustroot import TrustRoot, verifyReturnTo
+from openid.association import Association, default_negotiator, getSecretSize
+from openid.message import Message, InvalidOpenIDNamespace, \
+     OPENID_NS, OPENID2_NS, IDENTIFIER_SELECT, OPENID1_URL_LIMIT
 from openid.urinorm import urinorm
 
-_LOGGER = logging.getLogger(__name__)
-
 HTTP_OK = 200
 HTTP_REDIRECT = 302
 HTTP_ERROR = 400
@@ -144,32 +142,14 @@ ENCODE_HTML_FORM = ('HTML form',)
 
 UNUSED = None
 
-
 class OpenIDRequest(object):
     """I represent an incoming OpenID request.
 
     @cvar mode: the C{X{openid.mode}} of this request.
     @type mode: str
-
-    @ivar message: Original request message.
-    @type message: Message
     """
     mode = None
 
-    def __init__(self, message=None):
-        if message is not None:
-            self.message = message
-        else:
-            # If no message is defined, create an empty one.
-            self.message = Message(OPENID2_NS)
-
-    @property
-    def namespace(self):
-        """Return request namespace."""
-        msg = 'The "namespace" attribute of {} objects is deprecated. Use "message.getOpenIDNamespace()" instead'
-        warnings.warn(msg.format(type(self).__name__), DeprecationWarning, stacklevel=2)
-        return self.message.getOpenIDNamespace()
-
 
 class CheckAuthRequest(OpenIDRequest):
     """A request to verify the validity of a previous response.
@@ -193,7 +173,7 @@ class CheckAuthRequest(OpenIDRequest):
 
     required_fields = ["identity", "return_to", "response_nonce"]
 
-    def __init__(self, assoc_handle, signed, invalidate_handle=None, message=None):
+    def __init__(self, assoc_handle, signed, invalidate_handle=None):
         """Construct me.
 
         These parameters are assigned directly as class attributes, see
@@ -203,12 +183,12 @@ class CheckAuthRequest(OpenIDRequest):
         @type signed: L{Message}
         @type invalidate_handle: str
         """
-        super(CheckAuthRequest, self).__init__(message=message)
         self.assoc_handle = assoc_handle
         self.signed = signed
         self.invalidate_handle = invalidate_handle
+        self.namespace = OPENID2_NS
+
 
-    @classmethod
     def fromMessage(klass, message, op_endpoint=UNUSED):
         """Construct me from an OpenID Message.
 
@@ -217,24 +197,32 @@ class CheckAuthRequest(OpenIDRequest):
 
         @returntype: L{CheckAuthRequest}
         """
-        assoc_handle = message.getArg(OPENID_NS, 'assoc_handle')
-        sig = message.getArg(OPENID_NS, 'sig')
-        invalidate_handle = message.getArg(OPENID_NS, 'invalidate_handle')
-        if (assoc_handle is None or sig is None):
-            fmt = "%s request missing required parameter from message %s"
-            raise ProtocolError(message, text=fmt % (klass.mode, message))
+        self = klass.__new__(klass)
+        self.message = message
+        self.namespace = message.getOpenIDNamespace()
+        self.assoc_handle = message.getArg(OPENID_NS, 'assoc_handle')
+        self.sig = message.getArg(OPENID_NS, 'sig')
 
-        signed = message.copy()
+        if (self.assoc_handle is None or
+            self.sig is None):
+            fmt = "%s request missing required parameter from message %s"
+            raise ProtocolError(
+                message, text=fmt % (self.mode, message))
+
+        self.invalidate_handle = message.getArg(OPENID_NS, 'invalidate_handle')
+
+        self.signed = message.copy()
         # openid.mode is currently check_authentication because
         # that's the mode of this request.  But the signature
         # was made on something with a different openid.mode.
         # http://article.gmane.org/gmane.comp.web.openid.general/537
-        if signed.hasKey(OPENID_NS, "mode"):
-            signed.setArg(OPENID_NS, "mode", "id_res")
+        if self.signed.hasKey(OPENID_NS, "mode"):
+            self.signed.setArg(OPENID_NS, "mode", "id_res")
 
-        self = klass(assoc_handle, signed, invalidate_handle, message)
         return self
 
+    fromMessage = classmethod(fromMessage)
+
     def answer(self, signatory):
         """Respond to this request.
 
@@ -263,13 +251,15 @@ class CheckAuthRequest(OpenIDRequest):
                     OPENID_NS, 'invalidate_handle', self.invalidate_handle)
         return response
 
+
     def __str__(self):
         if self.invalidate_handle:
             ih = " invalidate? %r" % (self.invalidate_handle,)
         else:
             ih = ""
-        sig = self.message.getArg(OPENID_NS, 'sig')
-        s = "<%s handle: %r sig: %r: signed: %r%s>" % (self.__class__.__name__, self.assoc_handle, sig, self.signed, ih)
+        s = "<%s handle: %r sig: %r: signed: %r%s>" % (
+            self.__class__.__name__, self.assoc_handle,
+            self.sig, self.signed, ih)
         return s
 
 
@@ -289,10 +279,11 @@ class PlainTextServerSession(object):
     session_type = 'no-encryption'
     allowed_assoc_types = ['HMAC-SHA1', 'HMAC-SHA256']
 
-    @classmethod
     def fromMessage(cls, unused_request):
         return cls()
 
+    fromMessage = classmethod(fromMessage)
+
     def answer(self, secret):
         return {'mac_key': oidutil.toBase64(secret)}
 
@@ -324,7 +315,6 @@ class DiffieHellmanSHA1ServerSession(object):
         self.dh = dh
         self.consumer_pubkey = consumer_pubkey
 
-    @classmethod
     def fromMessage(cls, message):
         """
         @param message: The associate request message
@@ -338,7 +328,7 @@ class DiffieHellmanSHA1ServerSession(object):
         dh_modulus = message.getArg(OPENID_NS, 'dh_modulus')
         dh_gen = message.getArg(OPENID_NS, 'dh_gen')
         if (dh_modulus is None and dh_gen is not None or
-                dh_gen is None and dh_modulus is not None):
+            dh_gen is None and dh_modulus is not None):
 
             if dh_modulus is None:
                 missing = 'modulus'
@@ -366,6 +356,8 @@ class DiffieHellmanSHA1ServerSession(object):
 
         return cls(dh, consumer_pubkey)
 
+    fromMessage = classmethod(fromMessage)
+
     def answer(self, secret):
         mac_key = self.dh.xorSecret(self.consumer_pubkey,
                                     secret,
@@ -373,15 +365,13 @@ class DiffieHellmanSHA1ServerSession(object):
         return {
             'dh_server_public': cryptutil.longToBase64(self.dh.public),
             'enc_mac_key': oidutil.toBase64(mac_key),
-        }
-
+            }
 
 class DiffieHellmanSHA256ServerSession(DiffieHellmanSHA1ServerSession):
     session_type = 'DH-SHA256'
     hash_func = staticmethod(cryptutil.sha256)
     allowed_assoc_types = ['HMAC-SHA256']
 
-
 class AssociateRequest(OpenIDRequest):
     """A request to establish an X{association}.
 
@@ -405,19 +395,20 @@ class AssociateRequest(OpenIDRequest):
         'no-encryption': PlainTextServerSession,
         'DH-SHA1': DiffieHellmanSHA1ServerSession,
         'DH-SHA256': DiffieHellmanSHA256ServerSession,
-    }
+        }
 
-    def __init__(self, session, assoc_type, message=None):
+    def __init__(self, session, assoc_type):
         """Construct me.
 
         The session is assigned directly as a class attribute. See my
         L{class documentation<AssociateRequest>} for its description.
         """
-        super(AssociateRequest, self).__init__(message=message)
+        super(AssociateRequest, self).__init__()
         self.session = session
         self.assoc_type = assoc_type
+        self.namespace = OPENID2_NS
+
 
-    @classmethod
     def fromMessage(klass, message, op_endpoint=UNUSED):
         """Construct me from an OpenID Message.
 
@@ -429,25 +420,16 @@ class AssociateRequest(OpenIDRequest):
         if message.isOpenID1():
             session_type = message.getArg(OPENID_NS, 'session_type')
             if session_type == 'no-encryption':
-                _LOGGER.warn('Received OpenID 1 request with a no-encryption '
-                             'assocaition session type. Continuing anyway.')
+                oidutil.log('Received OpenID 1 request with a no-encryption '
+                            'assocaition session type. Continuing anyway.')
             elif not session_type:
                 session_type = 'no-encryption'
-
-            # in 1.0 assoc_type has default
-            assoc_type = message.getArg(OPENID_NS, 'assoc_type', 'HMAC-SHA1')
         else:
             session_type = message.getArg(OPENID2_NS, 'session_type')
             if session_type is None:
                 raise ProtocolError(message,
                                     text="session_type missing from request")
 
-            # in 2.0 assoc_type is required
-            assoc_type = message.getArg(OPENID2_NS, 'assoc_type')
-            if assoc_type is None:
-                raise ProtocolError(message,
-                                    text="assoc_type missing from request")
-
         try:
             session_class = klass.session_classes[session_type]
         except KeyError:
@@ -456,17 +438,22 @@ class AssociateRequest(OpenIDRequest):
 
         try:
             session = session_class.fromMessage(message)
-        except ValueError as why:
+        except ValueError, why:
             raise ProtocolError(message, 'Error parsing %s session: %s' %
                                 (session_class.session_type, why[0]))
 
+        assoc_type = message.getArg(OPENID_NS, 'assoc_type', 'HMAC-SHA1')
         if assoc_type not in session.allowed_assoc_types:
             fmt = 'Session type %s does not support association type %s'
             raise ProtocolError(message, fmt % (session_type, assoc_type))
 
-        self = klass(session, assoc_type, message=message)
+        self = klass(session, assoc_type)
+        self.message = message
+        self.namespace = message.getOpenIDNamespace()
         return self
 
+    fromMessage = classmethod(fromMessage)
+
     def answer(self, assoc):
         """Respond to this request with an X{association}.
 
@@ -482,7 +469,7 @@ class AssociateRequest(OpenIDRequest):
             'expires_in': '%d' % (assoc.getExpiresIn(),),
             'assoc_type': self.assoc_type,
             'assoc_handle': assoc.handle,
-        })
+            })
         response.fields.updateArgs(OPENID_NS,
                                    self.session.answer(assoc.secret))
 
@@ -516,7 +503,6 @@ class AssociateRequest(OpenIDRequest):
 
         return response
 
-
 class CheckIDRequest(OpenIDRequest):
     """A request to confirm the identity of a user.
 
@@ -534,7 +520,7 @@ class CheckIDRequest(OpenIDRequest):
 
     @ivar claimed_id: The claimed identifier.  Not present in OpenID 1.x
         messages.
-    @type claimed_id: str or None
+    @type claimed_id: str
 
     @ivar trust_root: "Are you Frank?" asks the checkid request.  "Who wants
         to know?"  C{trust_root}, that's who.  This URL identifies the party
@@ -553,7 +539,7 @@ class CheckIDRequest(OpenIDRequest):
     """
 
     def __init__(self, identity, return_to, trust_root=None, immediate=False,
-                 assoc_handle=None, op_endpoint=None, claimed_id=None, message=None):
+                 assoc_handle=None, op_endpoint=None, claimed_id=None):
         """Construct me.
 
         These parameters are assigned directly as class attributes, see
@@ -561,33 +547,13 @@ class CheckIDRequest(OpenIDRequest):
 
         @raises MalformedReturnURL: When the C{return_to} URL is not a URL.
         """
-        super(CheckIDRequest, self).__init__(message=message)
         self.assoc_handle = assoc_handle
-
-        # Check the identifier validity. In case of error, create protocol error from the message in the argument.
-        if self.message.isOpenID1():
-            if identity is None:
-                s = "OpenID 1 message did not contain openid.identity"
-                raise ProtocolError(message, text=s)
-        else:
-            if identity and not claimed_id:
-                s = ("OpenID 2.0 message contained openid.identity but not "
-                     "claimed_id")
-                raise ProtocolError(message, text=s)
-            elif claimed_id and not identity:
-                s = ("OpenID 2.0 message contained openid.claimed_id but not "
-                     "identity")
-                raise ProtocolError(message, text=s)
-
         self.identity = identity
-        self.claimed_id = claimed_id
+        self.claimed_id = claimed_id or identity
         self.return_to = return_to
         self.trust_root = trust_root or return_to
-
-        if self.message.isOpenID2() and op_endpoint is None:
-            raise ValueError("CheckIDRequest requires op_endpoint argument for OpenID 2.0 requests.")
         self.op_endpoint = op_endpoint
-
+        assert self.op_endpoint is not None
         if immediate:
             self.immediate = True
             self.mode = "checkid_immediate"
@@ -595,24 +561,21 @@ class CheckIDRequest(OpenIDRequest):
             self.immediate = False
             self.mode = "checkid_setup"
 
-        # Using TrustRoot.parse here is a bit misleading, as we're not
-        # parsing return_to as a trust root at all.  However, valid URLs
-        # are valid trust roots, so we can use this to get an idea if it
-        # is a valid URL.  Not all trust roots are valid return_to URLs,
-        # however (particularly ones with wildcards), so this is still a
-        # little sketchy.
-        if self.return_to is not None and not TrustRoot.parse(self.return_to):
-            raise MalformedReturnURL(message, self.return_to)
-
-        # I first thought that checking to see if the return_to is within
-        # the trust_root is premature here, a logic-not-decoding thing.  But
-        # it was argued that this is really part of data validation.  A
-        # request with an invalid trust_root/return_to is broken regardless of
-        # application, right?
+        if self.return_to is not None and \
+               not TrustRoot.parse(self.return_to):
+            raise MalformedReturnURL(None, self.return_to)
         if not self.trustRootValid():
-            raise UntrustedReturnURL(message, self.return_to, self.trust_root)
+            raise UntrustedReturnURL(None, self.return_to, self.trust_root)
+        self.message = None
+
+    def _getNamespace(self):
+        warnings.warn('The "namespace" attribute of CheckIDRequest objects '
+                      'is deprecated. Use "message.getOpenIDNamespace()" '
+                      'instead', DeprecationWarning, stacklevel=2)
+        return self.message.getOpenIDNamespace()
+
+    namespace = property(_getNamespace)
 
-    @classmethod
     def fromMessage(klass, message, op_endpoint):
         """Construct me from an OpenID message.
 
@@ -633,17 +596,38 @@ class CheckIDRequest(OpenIDRequest):
 
         @returntype: L{CheckIDRequest}
         """
+        self = klass.__new__(klass)
+        self.message = message
+        self.op_endpoint = op_endpoint
         mode = message.getArg(OPENID_NS, 'mode')
-        assert mode in ('checkid_immediate', 'checkid_setup')
-        immediate = bool(mode == 'checkid_immediate')
+        if mode == "checkid_immediate":
+            self.immediate = True
+            self.mode = "checkid_immediate"
+        else:
+            self.immediate = False
+            self.mode = "checkid_setup"
 
-        return_to = message.getArg(OPENID_NS, 'return_to')
-        if message.isOpenID1() and not return_to:
+        self.return_to = message.getArg(OPENID_NS, 'return_to')
+        if message.isOpenID1() and not self.return_to:
             fmt = "Missing required field 'return_to' from %r"
             raise ProtocolError(message, text=fmt % (message,))
 
-        identity = message.getArg(OPENID_NS, 'identity')
-        claimed_id = message.getArg(OPENID_NS, 'claimed_id')
+        self.identity = message.getArg(OPENID_NS, 'identity')
+        self.claimed_id = message.getArg(OPENID_NS, 'claimed_id')
+        if message.isOpenID1():
+            if self.identity is None:
+                s = "OpenID 1 message did not contain openid.identity"
+                raise ProtocolError(message, text=s)
+        else:
+            if self.identity and not self.claimed_id:
+                s = ("OpenID 2.0 message contained openid.identity but not "
+                     "claimed_id")
+                raise ProtocolError(message, text=s)
+            elif self.claimed_id and not self.identity:
+                s = ("OpenID 2.0 message contained openid.claimed_id but not "
+                     "identity")
+                raise ProtocolError(message, text=s)
+
         # There's a case for making self.trust_root be a TrustRoot
         # here.  But if TrustRoot isn't currently part of the "public" API,
         # I'm not sure it's worth doing.
@@ -656,17 +640,38 @@ class CheckIDRequest(OpenIDRequest):
         # Using 'or' here is slightly different than sending a default
         # argument to getArg, as it will treat no value and an empty
         # string as equivalent.
-        trust_root = (message.getArg(OPENID_NS, trust_root_param) or return_to)
+        self.trust_root = (message.getArg(OPENID_NS, trust_root_param)
+                           or self.return_to)
 
-        if not message.isOpenID1() and (return_to is trust_root is None):
-            raise ProtocolError(message, "openid.realm required when openid.return_to absent")
+        if not message.isOpenID1():
+            if self.return_to is self.trust_root is None:
+                raise ProtocolError(message, "openid.realm required when " +
+                                    "openid.return_to absent")
 
-        assoc_handle = message.getArg(OPENID_NS, 'assoc_handle')
+        self.assoc_handle = message.getArg(OPENID_NS, 'assoc_handle')
+
+        # Using TrustRoot.parse here is a bit misleading, as we're not
+        # parsing return_to as a trust root at all.  However, valid URLs
+        # are valid trust roots, so we can use this to get an idea if it
+        # is a valid URL.  Not all trust roots are valid return_to URLs,
+        # however (particularly ones with wildcards), so this is still a
+        # little sketchy.
+        if self.return_to is not None and \
+               not TrustRoot.parse(self.return_to):
+            raise MalformedReturnURL(message, self.return_to)
+
+        # I first thought that checking to see if the return_to is within
+        # the trust_root is premature here, a logic-not-decoding thing.  But
+        # it was argued that this is really part of data validation.  A
+        # request with an invalid trust_root/return_to is broken regardless of
+        # application, right?
+        if not self.trustRootValid():
+            raise UntrustedReturnURL(message, self.return_to, self.trust_root)
 
-        self = klass(identity, return_to, trust_root=trust_root, immediate=immediate, assoc_handle=assoc_handle,
-                     op_endpoint=op_endpoint, claimed_id=claimed_id, message=message)
         return self
 
+    fromMessage = classmethod(fromMessage)
+
     def idSelect(self):
         """Is the identifier to be selected by the IDP?
 
@@ -766,6 +771,8 @@ class CheckIDRequest(OpenIDRequest):
 
         @raises NoReturnError: when I do not have a return_to.
         """
+        assert self.message is not None
+
         if not self.return_to:
             raise NoReturnToError
 
@@ -781,10 +788,10 @@ class CheckIDRequest(OpenIDRequest):
         if allow:
             mode = 'id_res'
         elif self.message.isOpenID1():
-            if self.immediate:
-                mode = 'id_res'
-            else:
-                mode = 'cancel'
+             if self.immediate:
+                 mode = 'id_res'
+             else:
+                 mode = 'cancel'
         else:
             if self.immediate:
                 mode = 'setup_needed'
@@ -812,7 +819,8 @@ class CheckIDRequest(OpenIDRequest):
                     normalized_request_identity = urinorm(self.identity)
                     normalized_answer_identity = urinorm(identity)
 
-                    if normalized_request_identity != normalized_answer_identity:
+                    if (normalized_request_identity !=
+                        normalized_answer_identity):
                         raise ValueError(
                             "Request was for identity %r, cannot reply "
                             "with identity %r" % (self.identity, identity))
@@ -833,13 +841,13 @@ class CheckIDRequest(OpenIDRequest):
                 raise ValueError(
                     "Request was an OpenID 1 request, so response must "
                     "include an identifier."
-                )
+                    )
 
             response.fields.updateArgs(OPENID_NS, {
                 'mode': mode,
                 'return_to': self.return_to,
                 'response_nonce': mkNonce(),
-            })
+                })
 
             if server_url:
                 response.fields.setArg(OPENID_NS, 'op_endpoint', server_url)
@@ -870,6 +878,7 @@ class CheckIDRequest(OpenIDRequest):
 
         return response
 
+
     def encodeToURL(self, server_url):
         """Encode this request as a URL to GET.
 
@@ -903,6 +912,7 @@ class CheckIDRequest(OpenIDRequest):
         response.updateArgs(OPENID_NS, q)
         return response.toURL(server_url)
 
+
     def getCancelURL(self):
         """Get the URL to cancel this request.
 
@@ -929,6 +939,7 @@ class CheckIDRequest(OpenIDRequest):
         response.setArg(OPENID_NS, 'mode', 'cancel')
         return response.toURL(self.return_to)
 
+
     def __repr__(self):
         return '<%s id:%r im:%s tr:%r ah:%r>' % (self.__class__.__name__,
                                                  self.identity,
@@ -937,6 +948,7 @@ class CheckIDRequest(OpenIDRequest):
                                                  self.assoc_handle)
 
 
+
 class OpenIDResponse(object):
     """I am a response to an OpenID request.
 
@@ -965,7 +977,7 @@ class OpenIDResponse(object):
         @type request: L{OpenIDRequest}
         """
         self.request = request
-        self.fields = Message(request.message.getOpenIDNamespace())
+        self.fields = Message(request.namespace)
 
     def __str__(self):
         return "%s for %s: %s" % (
@@ -973,6 +985,7 @@ class OpenIDResponse(object):
             self.request.__class__.__name__,
             self.fields)
 
+
     def toFormMarkup(self, form_tag_attrs=None):
         """Returns the form markup for this response.
 
@@ -1010,6 +1023,7 @@ class OpenIDResponse(object):
         """
         return self.whichEncoding() == ENCODE_HTML_FORM
 
+
     def needsSigning(self):
         """Does this response require signing?
 
@@ -1017,6 +1031,7 @@ class OpenIDResponse(object):
         """
         return self.fields.getArg(OPENID_NS, 'mode') == 'id_res'
 
+
     # implements IEncodable
 
     def whichEncoding(self):
@@ -1027,15 +1042,15 @@ class OpenIDResponse(object):
         @change: 2.1.0 added the ENCODE_HTML_FORM response.
         """
         if self.request.mode in BROWSER_REQUEST_MODES:
-            if self.fields.isOpenID2() and \
+            if self.fields.getOpenIDNamespace() == OPENID2_NS and \
                len(self.encodeToURL()) > OPENID1_URL_LIMIT:
-                # Message can be encoded as HTML form only if it's OpenID 2.0.
                 return ENCODE_HTML_FORM
             else:
                 return ENCODE_URL
         else:
             return ENCODE_KVFORM
 
+
     def encodeToURL(self):
         """Encode a response as a URL for the user agent to GET.
 
@@ -1046,6 +1061,7 @@ class OpenIDResponse(object):
         """
         return self.fields.toURL(self.request.return_to)
 
+
     def addExtension(self, extension_response):
         """
         Add an extension response to this response message.
@@ -1059,6 +1075,7 @@ class OpenIDResponse(object):
         """
         extension_response.toMessage(self.fields)
 
+
     def encodeToKVForm(self):
         """Encode a response in key-value colon/newline format.
 
@@ -1073,6 +1090,7 @@ class OpenIDResponse(object):
         return self.fields.toKVForm()
 
 
+
 class WebResponse(object):
     """I am a response to an OpenID request in terms a web server understands.
 
@@ -1103,6 +1121,7 @@ class WebResponse(object):
         self.body = body
 
 
+
 class Signatory(object):
     """I sign things.
 
@@ -1116,7 +1135,7 @@ class Signatory(object):
     @type SECRET_LIFETIME: int
     """
 
-    SECRET_LIFETIME = 14 * 24 * 60 * 60  # 14 days, in seconds
+    SECRET_LIFETIME = 14 * 24 * 60 * 60 # 14 days, in seconds
 
     # keys have a bogus server URL in them because the filestore
     # really does expect that key to be a URL.  This seems a little
@@ -1125,6 +1144,7 @@ class Signatory(object):
     _normal_key = 'http://localhost/|normal'
     _dumb_key = 'http://localhost/|dumb'
 
+
     def __init__(self, store):
         """Create a new Signatory.
 
@@ -1134,6 +1154,7 @@ class Signatory(object):
         assert store is not None
         self.store = store
 
+
     def verify(self, assoc_handle, message):
         """Verify that the signature for some data is valid.
 
@@ -1149,16 +1170,21 @@ class Signatory(object):
         """
         assoc = self.getAssociation(assoc_handle, dumb=True)
         if not assoc:
-            _LOGGER.error("failed to get assoc with handle %r to verify message %r", assoc_handle, message)
+            oidutil.log("failed to get assoc with handle %r to verify "
+                        "message %r"
+                        % (assoc_handle, message))
             return False
 
         try:
             valid = assoc.checkMessageSignature(message)
-        except ValueError as ex:
-            _LOGGER.exception("Error in verifying %s with %s: %s", message, assoc, ex)
+        except ValueError, ex:
+            oidutil.log("Error in verifying %s with %s: %s" % (message,
+                                                               assoc,
+                                                               ex))
             return False
         return valid
 
+
     def sign(self, response):
         """Sign a response.
 
@@ -1199,10 +1225,11 @@ class Signatory(object):
 
         try:
             signed_response.fields = assoc.signMessage(signed_response.fields)
-        except kvform.KVFormError as err:
+        except kvform.KVFormError, err:
             raise EncodingError(response, explanation=str(err))
         return signed_response
 
+
     def createAssociation(self, dumb=True, assoc_type='HMAC-SHA1'):
         """Make a new association.
 
@@ -1230,6 +1257,7 @@ class Signatory(object):
         self.store.storeAssociation(key, assoc)
         return assoc
 
+
     def getAssociation(self, assoc_handle, dumb, checkExpiration=True):
         """Get the association with the specified handle.
 
@@ -1257,13 +1285,15 @@ class Signatory(object):
             key = self._normal_key
         assoc = self.store.getAssociation(key, assoc_handle)
         if assoc is not None and assoc.expiresIn <= 0:
-            _LOGGER.info("requested %sdumb key %r is expired (by %s seconds)",
-                         (not dumb) and 'not-' or '', assoc_handle, assoc.expiresIn)
+            oidutil.log("requested %sdumb key %r is expired (by %s seconds)" %
+                        ((not dumb) and 'not-' or '',
+                         assoc_handle, assoc.expiresIn))
             if checkExpiration:
                 self.store.removeAssociation(key, assoc_handle)
                 assoc = None
         return assoc
 
+
     def invalidate(self, assoc_handle, dumb):
         """Invalidates the association with the given handle.
 
@@ -1279,6 +1309,7 @@ class Signatory(object):
         self.store.removeAssociation(key, assoc_handle)
 
 
+
 class Encoder(object):
     """I encode responses in to L{WebResponses<WebResponse>}.
 
@@ -1290,6 +1321,7 @@ class Encoder(object):
 
     responseFactory = WebResponse
 
+
     def encode(self, response):
         """Encode a response to a L{WebResponse}.
 
@@ -1307,7 +1339,7 @@ class Encoder(object):
                                       headers={'location': location})
         elif encode_as == ENCODE_HTML_FORM:
             wr = self.responseFactory(code=HTTP_OK,
-                                      body=response.toHTML())
+                                      body=response.toFormMarkup())
         else:
             # Can't encode this to a protocol message.  You should probably
             # render it to HTML and show it to the user.
@@ -1315,6 +1347,7 @@ class Encoder(object):
         return wr
 
 
+
 class SigningEncoder(Encoder):
     """I encode responses in to L{WebResponses<WebResponse>}, signing them when required.
     """
@@ -1327,6 +1360,7 @@ class SigningEncoder(Encoder):
         """
         self.signatory = signatory
 
+
     def encode(self, response):
         """Encode a response to a L{WebResponse}, signing it first if appropriate.
 
@@ -1350,6 +1384,7 @@ class SigningEncoder(Encoder):
         return super(SigningEncoder, self).encode(response)
 
 
+
 class Decoder(object):
     """I decode an incoming web request in to a L{OpenIDRequest}.
     """
@@ -1359,7 +1394,7 @@ class Decoder(object):
         'checkid_immediate': CheckIDRequest.fromMessage,
         'check_authentication': CheckAuthRequest.fromMessage,
         'associate': AssociateRequest.fromMessage,
-    }
+        }
 
     def __init__(self, server):
         """Construct a Decoder.
@@ -1390,7 +1425,7 @@ class Decoder(object):
 
         try:
             message = Message.fromPostArgs(query)
-        except InvalidOpenIDNamespace as err:
+        except InvalidOpenIDNamespace, err:
             # It's useful to have a Message attached to a ProtocolError, so we
             # override the bad ns value to build a Message out of it.  Kinda
             # kludgy, since it's made of lies, but the parts that aren't lies
@@ -1399,12 +1434,6 @@ class Decoder(object):
             query['openid.ns'] = OPENID2_NS
             message = Message.fromPostArgs(query)
             raise ProtocolError(message, str(err))
-        except InvalidNamespace as err:
-            # If openid.ns is OK, but there is problem with other namespaces
-            # We keep only bare parts of query and we try to make a ProtocolError from it
-            query = [(key, value) for key, value in query.items() if key.count('.') < 2]
-            message = Message.fromPostArgs(dict(query))
-            raise ProtocolError(message, str(err))
 
         mode = message.getArg(OPENID_NS, 'mode')
         if not mode:
@@ -1414,6 +1443,7 @@ class Decoder(object):
         handler = self._handlers.get(mode, self.defaultDecoder)
         return handler(message, self.server.op_endpoint)
 
+
     def defaultDecoder(self, message, server):
         """Called to decode queries when no handler for that mode is found.
 
@@ -1425,6 +1455,7 @@ class Decoder(object):
         raise ProtocolError(message, text=fmt % (mode,))
 
 
+
 class Server(object):
     """I handle requests for an OpenID server.
 
@@ -1478,7 +1509,7 @@ class Server(object):
     encoderClass = SigningEncoder
     decoderClass = Decoder
 
-    def __init__(self, store, op_endpoint=None, signatoryClass=None, encoderClass=None, decoderClass=None):
+    def __init__(self, store, op_endpoint=None):
         """A new L{Server}.
 
         @param store: The back-end where my associations are stored.
@@ -1494,24 +1525,9 @@ class Server(object):
             if you want to respond to any version 2 OpenID requests.
         """
         self.store = store
-        if signatoryClass is None:
-            signatoryClass = self.signatoryClass
-            if signatoryClass != Server.signatoryClass:
-                warnings.warn("Attribute signatoryClass on Server class is deprecated."
-                              "Use signatoryClass argument of __init__ instead.", DeprecationWarning)
-        self.signatory = signatoryClass(self.store)
-        if encoderClass is None:
-            encoderClass = self.encoderClass
-            if encoderClass != Server.encoderClass:
-                warnings.warn("Attribute encoderClass on Server class is deprecated."
-                              "Use encoderClass argument of __init__ instead.", DeprecationWarning)
-        self.encoder = encoderClass(self.signatory)
-        if decoderClass is None:
-            decoderClass = self.decoderClass
-            if decoderClass != Server.decoderClass:
-                warnings.warn("Attribute decoderClass on Server class is deprecated."
-                              "Use decoderClass argument of __init__ instead.", DeprecationWarning)
-        self.decoder = decoderClass(self)
+        self.signatory = self.signatoryClass(self.store)
+        self.encoder = self.encoderClass(self.signatory)
+        self.decoder = self.decoderClass(self)
         self.negotiator = default_negotiator.copy()
 
         if not op_endpoint:
@@ -1521,6 +1537,7 @@ class Server(object):
                           stacklevel=2)
         self.op_endpoint = op_endpoint
 
+
     def handleRequest(self, request):
         """Handle a request.
 
@@ -1542,6 +1559,7 @@ class Server(object):
                 "%s has no handler for a request of mode %r." %
                 (self, request.mode))
 
+
     def openid_check_authentication(self, request):
         """Handle and respond to C{check_authentication} requests.
 
@@ -1549,6 +1567,7 @@ class Server(object):
         """
         return request.answer(self.signatory)
 
+
     def openid_associate(self, request):
         """Handle and respond to C{associate} requests.
 
@@ -1564,12 +1583,14 @@ class Server(object):
         else:
             message = ('Association type %r is not supported with '
                        'session type %r' % (assoc_type, session_type))
-            (preferred_assoc_type, preferred_session_type) = self.negotiator.getAllowedType()
+            (preferred_assoc_type, preferred_session_type) = \
+                                   self.negotiator.getAllowedType()
             return request.answerUnsupported(
                 message,
                 preferred_assoc_type,
                 preferred_session_type)
 
+
     def decodeRequest(self, query):
         """Transform query parameters into an L{OpenIDRequest}.
 
@@ -1589,6 +1610,7 @@ class Server(object):
         """
         return self.decoder.decode(query)
 
+
     def encodeResponse(self, response):
         """Encode a response to a L{WebResponse}, signing it first if appropriate.
 
@@ -1604,6 +1626,7 @@ class Server(object):
         return self.encoder.encode(response)
 
 
+
 class ProtocolError(Exception):
     """A message did not conform to the OpenID protocol.
 
@@ -1627,6 +1650,7 @@ class ProtocolError(Exception):
         assert type(message) not in [str, unicode]
         Exception.__init__(self, text)
 
+
     def getReturnTo(self):
         """Get the return_to argument from the request, if any.
 
@@ -1692,9 +1716,8 @@ class ProtocolError(Exception):
             displayed to the user.
         """
         if self.hasReturnTo():
-            if self.openid_message.isOpenID2() and \
+            if self.openid_message.getOpenIDNamespace() == OPENID2_NS and \
                len(self.encodeToURL()) > OPENID1_URL_LIMIT:
-                # Message can be encoded as HTML form only if it's OpenID 2.0.
                 return ENCODE_HTML_FORM
             else:
                 return ENCODE_URL
@@ -1721,11 +1744,13 @@ class ProtocolError(Exception):
         return None
 
 
+
 class VersionError(Exception):
     """Raised when an operation was attempted that is not compatible with
     the protocol version being used."""
 
 
+
 class NoReturnToError(Exception):
     """Raised when a response to a request cannot be generated because
     the request contains no return_to URL.
@@ -1733,6 +1758,7 @@ class NoReturnToError(Exception):
     pass
 
 
+
 class EncodingError(Exception):
     """Could not encode this as a protocol message.
 
@@ -1761,6 +1787,7 @@ class AlreadySigned(EncodingError):
     """This response is already signed."""
 
 
+
 class UntrustedReturnURL(ProtocolError):
     """A return_to is outside the trust_root."""
 
@@ -1776,12 +1803,12 @@ class UntrustedReturnURL(ProtocolError):
 
 class MalformedReturnURL(ProtocolError):
     """The return_to URL doesn't look like a valid URL."""
-
     def __init__(self, openid_message, return_to):
         self.return_to = return_to
         ProtocolError.__init__(self, openid_message)
 
 
+
 class MalformedTrustRoot(ProtocolError):
     """The trust root is not well-formed.
 
@@ -1790,7 +1817,7 @@ class MalformedTrustRoot(ProtocolError):
     pass
 
 
-# class IEncodable: # Interface
+#class IEncodable: # Interface
 #     def encodeToURL(return_to):
 #         """Encode a response as a URL for redirection.
 #
